@@ -17,10 +17,9 @@ from scipy.stats import mode
 from .object_storage import ObjectStorage
 ObjStorage = ObjectStorage()
 
-
 ###############
 # DATA
-###############S
+###############
 
 data_folder = os.environ['RAINFOREST_DATAPATH']
 metadata_folder = str(Path(data_folder, 'references', 'metadata'))
@@ -250,7 +249,7 @@ BORDER_SHP = shapefile.Reader(str(path_shp))
 FOLDER_DATABASE = '/store/msrad/radar/radar_database/'
 FOLDER_RADAR = '/store/msrad/radar/swiss/data/'
 FOLDER_RADARH = '/store/msrad/radar/polarHR/data/'
-FOLDER_CPCCV = '/store/msrad/radar/cpc_validation/'
+FOLDER_CPCCV = '/store/msrad/radar/cpc_validation/daily/'
 COSMO1_START = datetime.datetime(2015,10,1)
 COSMO1E_START = datetime.datetime(2019,7,2)
 FOLDER_RADAR = '/store/msrad/radar/swiss/data/'
@@ -318,10 +317,9 @@ SLURM_HEADER_R = '''#!/bin/sh
 #SBATCH -c 1      # cores requested
 #SBATCH -t 12:0:00  # time requested in hour:minute:second
 #SBATCH --partition=postproc
-#SBATCH --account=msrad
 #SBATCH --exclude=tsa-pp020,tsa-pp019,tsa-pp018
-#SBATCH --output="db_gauges-%A_%a.out"
-#SBATCH --error="db_gauges-%A_%a.err"
+#SBATCH --output="db_gauges_%A_%a.out"
+#SBATCH --error="db_gauges_%A_%a.err"
 #SBATCH --mail-type=END,FAIL
 #SBATCH --mail-user=rebecca.gugerli@meteoswiss.ch
 
@@ -338,10 +336,7 @@ SLURM_HEADER_PY = '''#!/bin/sh
 #SBATCH --mem-per-cpu 64g # memory in mbytes  
 #SBATCH -t 23:59:59  # time requested in hour:minute:second
 #SBATCH --partition=postproc
-#SBATCH --account=msrad
 #SBATCH --exclude=tsa-pp020,tsa-pp019,tsa-pp018
-#SBATCH --output="db_radar-%A_%a.out"
-#SBATCH --error="db_radar-%A_%a.err"
 #SBATCH --mail-type=END,FAIL
 #SBATCH --mail-user=rebecca.gugerli@meteoswiss.ch
 '''
